@@ -14,9 +14,9 @@
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.
 
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ You should have received a copy of the GNU General Public License along
+ with this program; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #include <locale.h>
@@ -220,7 +220,7 @@ static void ibus_array_engine_destroy (IBusArrayEngine *arrayeng) {
         arrayeng->table = NULL;
     }
 
-	IBUS_OBJECT_CLASS (parent_class)->destroy ((IBusObject *)arrayeng);
+    IBUS_OBJECT_CLASS (parent_class)->destroy ((IBusObject *)arrayeng);
 }
 
 static void ibus_array_engine_reset(IBusEngine *engine) {
@@ -229,7 +229,7 @@ static void ibus_array_engine_reset(IBusEngine *engine) {
     arrayeng->cursor_pos = 0;
     arrayeng->space_press_count = 0;
 
-    ibus_array_engine_update_preedit (arrayeng);
+    ibus_engine_hide_preedit_text (engine);
     ibus_engine_hide_lookup_table (engine);
     ibus_engine_hide_auxiliary_text (engine);
     parent_class->reset(engine);
